@@ -123,7 +123,6 @@ class Notizen(gtk.HBox):
 	def load_notes(self, data = None):
 		_moduleLogger.info("load_notes params: pos:"+str(self._pos)+" noteid:"+str(self.noteId))
 		self._noteslist.clear_items()
-		self._noteslist.append_item(_("New Note..."), "new")
 
 		self._categoryName = self._topBox.get_category()
 		search = self._topBox.get_search_pattern()
@@ -187,7 +186,7 @@ class Notizen(gtk.HBox):
 
 		try:
 			(pos, key, value) = self._noteslist.get_selection_data()
-			if (pos == -1):
+			if pos == -1:
 				return
 		except StandardError:
 			if data != "new":
